/*
 * --------------------------------------------------------------------------------------------------------------------
 * Example sketch/program showing how to read data from a PICC to serial.
 * --------------------------------------------------------------------------------------------------------------------
 * This is a MFRC522 library example; for further details and other examples see: https://github.com/miguelbalboa/rfid
 * 
 * Example sketch/program showing how to read data from a PICC (that is: a RFID Tag or Card) using a MFRC522 based RFID
 * Reader on the Arduino SPI interface.
 * 
 * When the Arduino and the MFRC522 module are connected (see the pin layout below), load this sketch into Arduino IDE
 * then verify/compile and upload it. To see the output: use Tools, Serial Monitor of the IDE (hit Ctrl+Shft+M). When
 * you present a PICC (that is: a RFID Tag or Card) at reading distance of the MFRC522 Reader/PCD, the serial output
 * will show the ID/UID, type and any data blocks it can read. Note: you may see "Timeout in communication" messages
 * when removing the PICC from reading distance too early.
 * 
 * If your reader supports it, this sketch/program will read all the PICCs presented (that is: multiple tag reading).
 * So if you stack two or more PICCs on top of each other and present them to the reader, it will first output all
 * details of the first and then the next PICC. Note that this may take some time as all data blocks are dumped, so
 * keep the PICCs at reading distance until complete.
 * 
 * @license Released into the public domain.
 * 
 * Typical pin layout used:
 * -----------------------------------------------------------------------------------------
 *             MFRC522      Arduino       Arduino   Arduino    Arduino          Arduino
 *             Reader/PCD   Uno/101       Mega      Nano v3    Leonardo/Micro   Pro Micro
 * Signal      Pin          Pin           Pin       Pin        Pin              Pin
 * -----------------------------------------------------------------------------------------
 * RST/Reset   RST          9             5         D9         RESET/ICSP-5     RST
 * SPI SS      SDA(SS)      10            53        D10        10               10
 * SPI MOSI    MOSI         11 / ICSP-4   51        D11        ICSP-4           16
 * SPI MISO    MISO         12 / ICSP-1   50        D12        ICSP-1           14
 * SPI SCK     SCK          13 / ICSP-3   52        D13        ICSP-3           15
 */
int state = 0;

#include <SPI.h>
#include <MFRC522.h>

#define RST_PIN         9          // Configurable, see typical pin layout above
#define SS_PIN          10         // Configurable, see typical pin layout above

MFRC522 mfrc522(SS_PIN, RST_PIN);  // Create MFRC522 instance

const int LED6= 7;
const int LED7= 6;
const int LED8= 5;
const int LED9= 4;
const int LED10= 2;

const int motorPin1 = 8;
int speed1 = 100;

int soundSensor = A0;

int sensory = 0;

void setup() {
  pinMode (LED6, OUTPUT);
pinMode (LED7, OUTPUT);
pinMode (LED8, OUTPUT);
pinMode (LED9, OUTPUT);
pinMode (LED10, OUTPUT);

pinMode(soundSensor, INPUT);
pinMode(motorPin1, OUTPUT);

  Serial.begin(9600);   // Initialize serial communications with the PC
  while (!Serial);    // Do nothing if no serial port is opened (added for Arduinos based on ATMEGA32U4)
  SPI.begin();      // Init SPI bus
  mfrc522.PCD_Init();   // Init MFRC522
  delay(4);       // Optional delay. Some board do need more time after init to be ready, see Readme
  mfrc522.PCD_DumpVersionToSerial();  // Show details of PCD - MFRC522 Card Reader details
  Serial.println(F("Scan PICC to see UID, SAK, type, and data blocks..."));
}

void loop() {

  //Serial.print(state);
  float soundData = analogRead(soundSensor);
  Serial.println(soundData);
  Serial.println(sensory);
  
  
  // Reset the loop if no new card present on the sensor/reader. This saves the entire process when idle.
  if ( ! mfrc522.PICC_IsNewCardPresent()) {
    return;
  }

  // Select one of the cards
  if ( ! mfrc522.PICC_ReadCardSerial()) {
    return;
  }

  // Dump debug info about the card; PICC_HaltA() is automatically called
   //mfrc522.PICC_DumpToSerial(&(mfrc522.uid));
  if (mfrc522.uid.uidByte[0] == 0x7a && 
     mfrc522.uid.uidByte[1] == 0xe7 &&
     mfrc522.uid.uidByte[2] == 0x91 &&
     mfrc522.uid.uidByte[3] == 0x19) {
      state = 1;
     //Serial.print(state);
    }

    if (mfrc522.uid.uidByte[0] == 0x0a && 
     mfrc522.uid.uidByte[1] == 0xc3 &&
     mfrc522.uid.uidByte[2] == 0x89 &&
     mfrc522.uid.uidByte[3] == 0x19) {
      state = 2;
     //Serial.print(state);
    }

    if (mfrc522.uid.uidByte[0] == 0x6a && 
     mfrc522.uid.uidByte[1] == 0xb2 &&
     mfrc522.uid.uidByte[2] == 0x8b &&
     mfrc522.uid.uidByte[3] == 0x19) {
      state = 3;
     //Serial.print(state);
    }

    if (mfrc522.uid.uidByte[0] == 0x19 && 
     mfrc522.uid.uidByte[1] == 0xa6 &&
     mfrc522.uid.uidByte[2] == 0xc4 &&
     mfrc522.uid.uidByte[3] == 0x99) {
      state = 4;
     //Serial.print(state);
    }

    if (mfrc522.uid.uidByte[0] == 0xb7 && 
     mfrc522.uid.uidByte[1] == 0x89 &&
     mfrc522.uid.uidByte[2] == 0x7e &&
     mfrc522.uid.uidByte[3] == 0x4a) {
      state = 5;
     //Serial.print(state);
    }

    if (state == 1)
    {
      digitalWrite (LED6, LOW);
      digitalWrite (LED7, LOW);
      digitalWrite (LED8, LOW);
      digitalWrite (LED9, LOW);
      digitalWrite (LED10, HIGH);
      delay(500);
      digitalWrite (LED10, LOW);
      delay(500);
      digitalWrite (LED10, HIGH);
      delay(500);
      digitalWrite (LED10, LOW);
      delay(500);
      digitalWrite (LED10, HIGH);
      delay(500);
      digitalWrite (LED10, LOW);
      delay(500);
      digitalWrite (LED10, HIGH);
    }

    if (state == 2)
    {
      digitalWrite (LED6, LOW);
      digitalWrite (LED7, LOW);
      digitalWrite (LED8, LOW);
      digitalWrite (LED10, HIGH);
      digitalWrite (LED9, HIGH);
      delay(500);
      digitalWrite (LED9, LOW);
      delay(500);
      digitalWrite (LED9, HIGH);
      delay(500);
      digitalWrite (LED9, LOW);
      delay(500);
      digitalWrite (LED9, HIGH);
      delay(500);
      digitalWrite (LED9, LOW);
      delay(500);
      digitalWrite (LED9, HIGH);
      }
 

    if (state == 3)
    {
      digitalWrite (LED6, LOW);
      digitalWrite (LED7, LOW);
      digitalWrite (LED9, HIGH);
      digitalWrite (LED10, HIGH);
      digitalWrite (LED8, HIGH);
      delay(500);
      digitalWrite (LED8, LOW);
      delay(500);
      digitalWrite (LED8, HIGH);
      delay(500);
      digitalWrite (LED8, LOW);
      delay(500);
      digitalWrite (LED8, HIGH);
      delay(500);
      digitalWrite (LED8, LOW);
      delay(500);
      digitalWrite (LED8, HIGH);
    }

    if (state == 4)
    {
      digitalWrite (LED6, LOW);
      digitalWrite (LED8, HIGH);
      digitalWrite (LED9, HIGH);
      digitalWrite (LED10, HIGH);
      digitalWrite (LED7, HIGH);
      delay(500);
      digitalWrite (LED7, LOW);
      delay(500);
      digitalWrite (LED7, HIGH);
      delay(500);
      digitalWrite (LED7, LOW);
      delay(500);
      digitalWrite (LED7, HIGH);
      delay(500);
      digitalWrite (LED7, LOW);
      delay(500);
      digitalWrite (LED7, HIGH);
    }

    if (state == 5)
    {
      digitalWrite (LED7, HIGH);
      digitalWrite (LED8, HIGH);
      digitalWrite (LED9, HIGH);
      digitalWrite (LED10, HIGH);
      digitalWrite (LED6, HIGH);
      delay(1000);
      digitalWrite (LED6, LOW);
      digitalWrite (LED7, LOW);
      digitalWrite (LED8, LOW);
      digitalWrite (LED9, LOW);
      digitalWrite (LED10, LOW);
      delay(1000);
      digitalWrite (LED7, HIGH);
      digitalWrite (LED8, HIGH);
      digitalWrite (LED9, HIGH);
      digitalWrite (LED10, HIGH);
      digitalWrite (LED6, HIGH);
      delay(1000);
      digitalWrite (LED6, LOW);
      digitalWrite (LED7, LOW);
      digitalWrite (LED8, LOW);
      digitalWrite (LED9, LOW);
      digitalWrite (LED10, LOW);
      delay(1000);
      digitalWrite (LED7, HIGH);
      digitalWrite (LED8, HIGH);
      digitalWrite (LED9, HIGH);
      digitalWrite (LED10, HIGH);
      digitalWrite (LED6, HIGH);
      delay(1000);
      digitalWrite (LED6, LOW);
      digitalWrite (LED7, LOW);
      digitalWrite (LED8, LOW);
      digitalWrite (LED9, LOW);
      digitalWrite (LED10, LOW);
      delay(1000);
    }

if(soundData > 300)
    {
      sensory = 1;
    }

    if(sensory == 1)
    {
      digitalWrite(motorPin1, speed1);
      delay(5000);
      digitalWrite(motorPin1, 0);
      delay(5000);
      digitalWrite(motorPin1, speed1);
      delay(5000);
      digitalWrite(motorPin1, 0);
      delay(5000);
      digitalWrite(motorPin1, speed1);
      delay(5000);
      digitalWrite(motorPin1, 0);
      delay(5000);
    }
}
